
/**
 * Wii definitions ***********************************************************
 */

#include "Wire.h" // This seems redundant, but we need to declare this
                  // dependency in the pde file or else it won't be included
                  // in the build.

#include "wiimote.h"

// Classic Controller Buttons
int bdl = 0; // D-Pad Left state
int bdr = 0; // D-Pad Right state
int bdu = 0; // D-Pad Up state
int bdd = 0; // D-Pad Down state
int ba = 0; // A button state
int bb = 0; // B button state
int bx = 0; // X button state
int by = 0; // Y button state
int bl = 0; // L button state
int br = 0; // R button state
int bm = 0; // MINUS button state
int bp = 0; // PLUS button state
int bhome = 0; // HOME button state
int bzl = 0; // ZL button state
int bzr = 0; // ZR button state

byte lx = calbuf[2]>>2;
byte ly = calbuf[5]>>2;
byte rx = calbuf[8]>>3;
byte ry = calbuf[11]>>3;


// Wiimote button data stream
byte *stream_callback(byte *buffer) {
	wiimote_write_buffer(buffer, bdl, bdr, bdu, bdd, ba, bb, bx, by, bl, br,
			bm, bp, bhome, lx, ly, rx, ry, bzl, bzr);

	return buffer;
}


/**
 * PS2 Definitions ************************************************************
 */

#include "PS2X_lib.h"  //for v1.6

#define PS2_DAT        13  //14    
#define PS2_CMD        11  //15
#define PS2_SEL        10  //16
#define PS2_CLK        12  //17

#define pressures   false
//#define pressures   false
#define rumble      false
//#define rumble      false

PS2X ps2x; // create PS2 Controller Class

int error = 0;
byte type = 0;
byte vibrate = 0;


void setup() {
/**
 * WII *****************************************************************************
 */
	wiimote_stream = stream_callback;
	wiimote_init();

/**
 * PS2 *****************************************************************************
 */
  
  delay(300);  //added delay to give wireless ps2 module some time to startup, before configuring it
  error = ps2x.config_gamepad(PS2_CLK, PS2_CMD, PS2_SEL, PS2_DAT, pressures, rumble);
  

}

/**
 * ps2ToWii allows converting PS2 analog axis values (max 255) to WII axis vaues(max 62)
 */
int ps2ToWii(int valorPlay) {

   /* local variable declaration */
   int result;
   result = valorPlay/255.0*62.0;

   return result; 
}

void loop() {

    ps2x.read_gamepad(false, vibrate); //read controller and set large motor to spin at 'vibrate' speed


    bdr = ps2x.Button(PSB_PAD_RIGHT);
    bdl = ps2x.Button(PSB_PAD_LEFT);
    bdu = ps2x.Button(PSB_PAD_UP);
    bdd = ps2x.Button(PSB_PAD_DOWN);
    
    ba = ps2x.Button(PSB_CIRCLE);
    bb = ps2x.Button(PSB_CROSS);
    bx = ps2x.Button(PSB_TRIANGLE);
    by = ps2x.Button(PSB_SQUARE);
    bl = ps2x.Button(PSB_L1);
    br = ps2x.Button(PSB_R1);
    bm = ps2x.Button(PSB_SELECT);
    bp = ps2x.Button(PSB_START);
    bhome = 0;
    bzl = ps2x.Button(PSB_L2);
    bzr = ps2x.Button(PSB_R2);
    
    lx = ps2ToWii(ps2x.Analog(PSS_LX));
    ly = ps2ToWii(255-ps2x.Analog(PSS_LY));
    rx = ps2ToWii(ps2x.Analog(PSS_RX));
    ry = ps2ToWii(255-ps2x.Analog(PSS_RY));
  
	delay(50);
}
